level_drop

Function level_drop 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn level_drop(level: *mut BookLevel)
Safety

level must be a live owning pointer returned by level_new or level_clone, and must not be used after this call.

Panics

Panics if level is null.